==> rdc_flutter_sdk-0.0.17.tar.gz: example/lib/screens/setting_detail/setting_detail.dart <==
import 'package:flutter/material.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';
import 'package:shop_app/size_config.dart';

class SettingDetailScreen extends StatelessWidget {
  static String routeName = "/setting_detail";

  const SettingDetailScreen({super.key});

  @override
  Widget build(BuildContext context) {
    final RabbitRequest data =
        ModalRoute.of(context)!.settings.arguments as RabbitRequest;

    SizeConfig().init(context);
    return Scaffold(
      appBar: AppBar(
          title: Text('Detail'),
          centerTitle: true,
          titleTextStyle: TextStyle(
              fontWeight: FontWeight.bold, fontSize: 24, color: Colors.black)),
      body: SingleChildScrollView(
        child: Container(
          child: Table(border: TableBorder.all(), children: [
            TableRow(children: [
              _padding(Text('memberId')),
              _padding(Text(data.memberId)),
            ]),
            TableRow(children: [
              _padding(Text(
                'ssoId',
              )),
              _padding(Text(data.ssoId)),
            ]),
            TableRow(children: [
              _padding(Text('globalId')),
              _padding(Text(data.globalId)),
            ]),
            TableRow(children: [
              _padding(Text('sdkVersion')),
              _padding(Text(data.sdkVersion)),
            ]),
            TableRow(children: [
              _padding(Text('sessionEvent')),
              _padding(Text(data.sessionEvent)),
            ]),
            TableRow(children: [
              _padding(Text('sessionId')),
              _padding(Text(data.sessionId)),
            ]),
            TableRow(children: [
              _padding(Text('touchPoint')),
              _padding(Text(data.touchPoint)),
            ]),
            TableRow(children: [
              _padding(Text('eventName')),
              _padding(Text(data.eventName)),
            ]),
            TableRow(children: [
              _padding(Text('eventValue')),
              _padding(Text(data.eventValue)),
            ]),
            TableRow(children: [
              _padding(Text('osVer')),
              _padding(Text(data.osVer)),
            ]),
            TableRow(children: [
              _padding(Text('osType')),
              _padding(Text(data.osType)),
            ]),
            TableRow(children: [
              _padding(Text('display')),
              _padding(Text(data.display)),
            ]),
            TableRow(children: [
              _padding(Text('localeCountry')),
              _padding(Text(data.localeCountry)),
            ]),
            TableRow(children: [
              _padding(Text('localeLang')),
              _padding(Text(data.localeLang)),
            ]),
            TableRow(children: [
              _padding(Text('latitude')),
              _padding(Text(data.latitude.toString())),
            ]),
            TableRow(children: [
              _padding(Text('longitude')),
              _padding(Text(data.longitude.toString())),
            ]),
            TableRow(children: [
              _padding(Text('maid')),
              _padding(Text(data.maid.toString())),
            ]),
            TableRow(children: [
              _padding(Text('device')),
              _padding(Text(data.device)),
            ]),
            TableRow(children: [
              _padding(Text('model')),
              _padding(Text(data.model)),
            ]),
            TableRow(children: [
              _padding(Text('brandName')),
              _padding(Text(data.brandName)),
            ]),
            TableRow(children: [
              _padding(Text('board')),
              _padding(Text(data.board)),
            ]),
            TableRow(children: [
              _padding(Text('appVer')),
              _padding(Text(data.appVer)),
            ]),
            TableRow(children: [
              _padding(Text('appVerNum')),
              _padding(Text(data.appVerNum)),
            ]),
            TableRow(children: [
              _padding(Text('prevAppVer')),
              _padding(Text(data.prevAppVer.toString())),
            ]),
            TableRow(children: [
              _padding(Text('prevAppVerNum')),
              _padding(Text(data.prevAppVerNum.toString())),
            ]),
            TableRow(children: [
              _padding(Text('dataLayer')),
              _padding(Text(data.dataLayer.toString())),
            ]),
            TableRow(children: [
              _padding(Text('time')),
              _padding(Text(data.time)),
            ]),
            TableRow(children: [
              _padding(Text('isSend')),
              _padding(Text(data.isSend.toString())),
            ]),
          ]),
        ),
      ),
    );
  }

  Widget _padding(Widget widget) {
    return Padding(
        padding: EdgeInsets.symmetric(horizontal: 2, vertical: 2),
        child: widget);
  }
}

// Column(
//   crossAxisAlignment: CrossAxisAlignment.start,
//   children: [
//     _padding(Text('memberId : ${data.memberId}'),
//     _padding(Text('ssoId : ${data.ssoId}'),
//     _padding(Text('globalId : ${data.globalId}'),
//     _padding(Text('sessionEvent : ${data.sessionEvent}'),
//     _padding(Text('sessionId : ${data.sessionId}'),
//     _padding(Text('touchPoint : ${data.touchPoint}'),
//     _padding(Text('eventName : ${data.eventName}'),
//     _padding(Text('eventValue : ${data.eventValue}'),
//     _padding(Text('osVer : ${data.osVer}'),
//     _padding(Text('osType : ${data.osType}'),
//     _padding(Text('display : ${data.display}'),
//     _padding(Text('localeCountry : ${data.localeCountry}'),
//     _padding(Text('localeLang : ${data.localeLang}'),
//     _padding(Text('latitude : ${data.latitude}'),
//     _padding(Text('longitude : ${data.longitude}'),
//     _padding(Text('maid : ${data.maid}'),
//     _padding(Text('device : ${data.device}'),
//     _padding(Text('model : ${data.model}'),
//     _padding(Text('brandName : ${data.brandName}'),
//     _padding(Text('board : ${data.board}'),
//     _padding(Text('appVer : ${data.appVer}'),
//     _padding(Text('appVerNum : ${data.appVerNum}'),
//     _padding(Text('prevAppVer : ${data.prevAppVer}'),
//     _padding(Text('prevAppVerNum : ${data.prevAppVerNum}'),
//     _padding(Text('dataLayer : ${data.dataLayer}'),
//     _padding(Text('time : ${data.time}'),
//     _padding(Text('isSend : ${data.isSend}'),
//   ],
// )

==> rdc_flutter_sdk_2-0.0.1-dev.1.tar.gz: example/lib/screens/setting_detail/setting_detail.dart <==
import 'package:flutter/material.dart';
import 'package:rdc_flutter_sdk_2/rabbit_data.dart';
import 'package:shop_app/size_config.dart';

class SettingDetailScreen extends StatelessWidget {
  static String routeName = "/setting_detail";

  const SettingDetailScreen();

  @override
  Widget build(BuildContext context) {
    final RabbitRequest data =
        ModalRoute.of(context)!.settings.arguments as RabbitRequest;

    SizeConfig().init(context);
    return Scaffold(
      appBar: AppBar(
          title: Text('Detail'),
          centerTitle: true,
          titleTextStyle: TextStyle(
              fontWeight: FontWeight.bold, fontSize: 24, color: Colors.black)),
      body: SingleChildScrollView(
        child: Container(
          child: Table(border: TableBorder.all(), children: [
            TableRow(children: [
              _padding(Text('memberId')),
              _padding(Text(data.memberId)),
            ]),
            TableRow(children: [
              _padding(Text(
                'ssoId',
              )),
              _padding(Text(data.ssoId)),
            ]),
            TableRow(children: [
              _padding(Text('globalId')),
              _padding(Text(data.globalId)),
            ]),
            TableRow(children: [
              _padding(Text('sdkVersion')),
              _padding(Text(data.sdkVersion)),
            ]),
            TableRow(children: [
              _padding(Text('sessionEvent')),
              _padding(Text(data.sessionEvent)),
            ]),
            TableRow(children: [
              _padding(Text('sessionId')),
              _padding(Text(data.sessionId)),
            ]),
            TableRow(children: [
              _padding(Text('touchPoint')),
              _padding(Text(data.touchPoint)),
            ]),
            TableRow(children: [
              _padding(Text('eventName')),
              _padding(Text(data.eventName)),
            ]),
            TableRow(children: [
              _padding(Text('eventValue')),
              _padding(Text(data.eventValue)),
            ]),
            TableRow(children: [
              _padding(Text('osVer')),
              _padding(Text(data.osVer)),
            ]),
            TableRow(children: [
              _padding(Text('osType')),
              _padding(Text(data.osType)),
            ]),
            TableRow(children: [
              _padding(Text('display')),
              _padding(Text(data.display)),
            ]),
            TableRow(children: [
              _padding(Text('localeCountry')),
              _padding(Text(data.localeCountry)),
            ]),
            TableRow(children: [
              _padding(Text('localeLang')),
              _padding(Text(data.localeLang)),
            ]),
            TableRow(children: [
              _padding(Text('latitude')),
              _padding(Text(data.latitude.toString())),
            ]),
            TableRow(children: [
              _padding(Text('longitude')),
              _padding(Text(data.longitude.toString())),
            ]),
            TableRow(children: [
              _padding(Text('maid')),
              _padding(Text(data.maid.toString())),
            ]),
            TableRow(children: [
              _padding(Text('device')),
              _padding(Text(data.device)),
            ]),
            TableRow(children: [
              _padding(Text('model')),
              _padding(Text(data.model)),
            ]),
            TableRow(children: [
              _padding(Text('brandName')),
              _padding(Text(data.brandName)),
            ]),
            TableRow(children: [
              _padding(Text('board')),
              _padding(Text(data.board)),
            ]),
            TableRow(children: [
              _padding(Text('appVer')),
              _padding(Text(data.appVer)),
            ]),
            TableRow(children: [
              _padding(Text('appVerNum')),
              _padding(Text(data.appVerNum)),
            ]),
            TableRow(children: [
              _padding(Text('prevAppVer')),
              _padding(Text(data.prevAppVer.toString())),
            ]),
            TableRow(children: [
              _padding(Text('prevAppVerNum')),
              _padding(Text(data.prevAppVerNum.toString())),
            ]),
            TableRow(children: [
              _padding(Text('dataLayer')),
              _padding(Text(data.dataLayer.toString())),
            ]),
            TableRow(children: [
              _padding(Text('time')),
              _padding(Text(data.time)),
            ]),
            TableRow(children: [
              _padding(Text('isSend')),
              _padding(Text(data.isSend.toString())),
            ]),
          ]),
        ),
      ),
    );
  }

  Widget _padding(Widget widget) {
    return Padding(
        padding: EdgeInsets.symmetric(horizontal: 2, vertical: 2),
        child: widget);
  }
}

// Column(
//   crossAxisAlignment: CrossAxisAlignment.start,
//   children: [
//     _padding(Text('memberId : ${data.memberId}'),
//     _padding(Text('ssoId : ${data.ssoId}'),
//     _padding(Text('globalId : ${data.globalId}'),
//     _padding(Text('sessionEvent : ${data.sessionEvent}'),
//     _padding(Text('sessionId : ${data.sessionId}'),
//     _padding(Text('touchPoint : ${data.touchPoint}'),
//     _padding(Text('eventName : ${data.eventName}'),
//     _padding(Text('eventValue : ${data.eventValue}'),
//     _padding(Text('osVer : ${data.osVer}'),
//     _padding(Text('osType : ${data.osType}'),
//     _padding(Text('display : ${data.display}'),
//     _padding(Text('localeCountry : ${data.localeCountry}'),
//     _padding(Text('localeLang : ${data.localeLang}'),
//     _padding(Text('latitude : ${data.latitude}'),
//     _padding(Text('longitude : ${data.longitude}'),
//     _padding(Text('maid : ${data.maid}'),
//     _padding(Text('device : ${data.device}'),
//     _padding(Text('model : ${data.model}'),
//     _padding(Text('brandName : ${data.brandName}'),
//     _padding(Text('board : ${data.board}'),
//     _padding(Text('appVer : ${data.appVer}'),
//     _padding(Text('appVerNum : ${data.appVerNum}'),
//     _padding(Text('prevAppVer : ${data.prevAppVer}'),
//     _padding(Text('prevAppVerNum : ${data.prevAppVerNum}'),
//     _padding(Text('dataLayer : ${data.dataLayer}'),
//     _padding(Text('time : ${data.time}'),
//     _padding(Text('isSend : ${data.isSend}'),
//   ],
// )
